==> cloudwatch-1.93.0-sources.jar: software/amazon/awscdk/services/cloudwatch/CfnMetricStreamProps.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * Properties for defining a `AWS::CloudWatch::MetricStream`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:22.283Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudwatch.$Module.class, fqn = "@aws-cdk/aws-cloudwatch.CfnMetricStreamProps")
@software.amazon.jsii.Jsii.Proxy(CfnMetricStreamProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnMetricStreamProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::CloudWatch::MetricStream.FirehoseArn`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getFirehoseArn();

    /**
     * `AWS::CloudWatch::MetricStream.RoleArn`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getRoleArn();

    /**
     * `AWS::CloudWatch::MetricStream.ExcludeFilters`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getExcludeFilters() {
        return null;
    }

    /**
     * `AWS::CloudWatch::MetricStream.IncludeFilters`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getIncludeFilters() {
        return null;
    }

    /**
     * `AWS::CloudWatch::MetricStream.Name`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getName() {
        return null;
    }

    /**
     * `AWS::CloudWatch::MetricStream.OutputFormat`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getOutputFormat() {
        return null;
    }

    /**
     * `AWS::CloudWatch::MetricStream.Tags`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnMetricStreamProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnMetricStreamProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnMetricStreamProps> {
        private java.lang.String firehoseArn;
        private java.lang.String roleArn;
        private java.lang.Object excludeFilters;
        private java.lang.Object includeFilters;
        private java.lang.String name;
        private java.lang.String outputFormat;
        private java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Sets the value of {@link CfnMetricStreamProps#getFirehoseArn}
         * @param firehoseArn `AWS::CloudWatch::MetricStream.FirehoseArn`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder firehoseArn(java.lang.String firehoseArn) {
            this.firehoseArn = firehoseArn;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricStreamProps#getRoleArn}
         * @param roleArn `AWS::CloudWatch::MetricStream.RoleArn`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder roleArn(java.lang.String roleArn) {
            this.roleArn = roleArn;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricStreamProps#getExcludeFilters}
         * @param excludeFilters `AWS::CloudWatch::MetricStream.ExcludeFilters`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder excludeFilters(software.amazon.awscdk.core.IResolvable excludeFilters) {
            this.excludeFilters = excludeFilters;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricStreamProps#getExcludeFilters}
         * @param excludeFilters `AWS::CloudWatch::MetricStream.ExcludeFilters`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder excludeFilters(java.util.List<? extends java.lang.Object> excludeFilters) {
            this.excludeFilters = excludeFilters;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricStreamProps#getIncludeFilters}
         * @param includeFilters `AWS::CloudWatch::MetricStream.IncludeFilters`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder includeFilters(software.amazon.awscdk.core.IResolvable includeFilters) {
            this.includeFilters = includeFilters;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricStreamProps#getIncludeFilters}
         * @param includeFilters `AWS::CloudWatch::MetricStream.IncludeFilters`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder includeFilters(java.util.List<? extends java.lang.Object> includeFilters) {
            this.includeFilters = includeFilters;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricStreamProps#getName}
         * @param name `AWS::CloudWatch::MetricStream.Name`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricStreamProps#getOutputFormat}
         * @param outputFormat `AWS::CloudWatch::MetricStream.OutputFormat`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder outputFormat(java.lang.String outputFormat) {
            this.outputFormat = outputFormat;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricStreamProps#getTags}
         * @param tags `AWS::CloudWatch::MetricStream.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.core.CfnTag> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnMetricStreamProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnMetricStreamProps build() {
            return new Jsii$Proxy(firehoseArn, roleArn, excludeFilters, includeFilters, name, outputFormat, tags);
        }
    }

    /**
     * An implementation for {@link CfnMetricStreamProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnMetricStreamProps {
        private final java.lang.String firehoseArn;
        private final java.lang.String roleArn;
        private final java.lang.Object excludeFilters;
        private final java.lang.Object includeFilters;
        private final java.lang.String name;
        private final java.lang.String outputFormat;
        private final java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.firehoseArn = software.amazon.jsii.Kernel.get(this, "firehoseArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.roleArn = software.amazon.jsii.Kernel.get(this, "roleArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.excludeFilters = software.amazon.jsii.Kernel.get(this, "excludeFilters", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.includeFilters = software.amazon.jsii.Kernel.get(this, "includeFilters", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.outputFormat = software.amazon.jsii.Kernel.get(this, "outputFormat", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final java.lang.String firehoseArn, final java.lang.String roleArn, final java.lang.Object excludeFilters, final java.lang.Object includeFilters, final java.lang.String name, final java.lang.String outputFormat, final java.util.List<? extends software.amazon.awscdk.core.CfnTag> tags) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.firehoseArn = java.util.Objects.requireNonNull(firehoseArn, "firehoseArn is required");
            this.roleArn = java.util.Objects.requireNonNull(roleArn, "roleArn is required");
            this.excludeFilters = excludeFilters;
            this.includeFilters = includeFilters;
            this.name = name;
            this.outputFormat = outputFormat;
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)tags;
        }

        @Override
        public final java.lang.String getFirehoseArn() {
            return this.firehoseArn;
        }

        @Override
        public final java.lang.String getRoleArn() {
            return this.roleArn;
        }

        @Override
        public final java.lang.Object getExcludeFilters() {
            return this.excludeFilters;
        }

        @Override
        public final java.lang.Object getIncludeFilters() {
            return this.includeFilters;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.lang.String getOutputFormat() {
            return this.outputFormat;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("firehoseArn", om.valueToTree(this.getFirehoseArn()));
            data.set("roleArn", om.valueToTree(this.getRoleArn()));
            if (this.getExcludeFilters() != null) {
                data.set("excludeFilters", om.valueToTree(this.getExcludeFilters()));
            }
            if (this.getIncludeFilters() != null) {
                data.set("includeFilters", om.valueToTree(this.getIncludeFilters()));
            }
            if (this.getName() != null) {
                data.set("name", om.valueToTree(this.getName()));
            }
            if (this.getOutputFormat() != null) {
                data.set("outputFormat", om.valueToTree(this.getOutputFormat()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudwatch.CfnMetricStreamProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnMetricStreamProps.Jsii$Proxy that = (CfnMetricStreamProps.Jsii$Proxy) o;

            if (!firehoseArn.equals(that.firehoseArn)) return false;
            if (!roleArn.equals(that.roleArn)) return false;
            if (this.excludeFilters != null ? !this.excludeFilters.equals(that.excludeFilters) : that.excludeFilters != null) return false;
            if (this.includeFilters != null ? !this.includeFilters.equals(that.includeFilters) : that.includeFilters != null) return false;
            if (this.name != null ? !this.name.equals(that.name) : that.name != null) return false;
            if (this.outputFormat != null ? !this.outputFormat.equals(that.outputFormat) : that.outputFormat != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.firehoseArn.hashCode();
            result = 31 * result + (this.roleArn.hashCode());
            result = 31 * result + (this.excludeFilters != null ? this.excludeFilters.hashCode() : 0);
            result = 31 * result + (this.includeFilters != null ? this.includeFilters.hashCode() : 0);
            result = 31 * result + (this.name != null ? this.name.hashCode() : 0);
            result = 31 * result + (this.outputFormat != null ? this.outputFormat.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}

==> cloudwatch-1.115.0-sources.jar: software/amazon/awscdk/services/cloudwatch/CfnMetricStreamProps.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * Properties for defining a `AWS::CloudWatch::MetricStream`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-07-21T15:55:57.891Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudwatch.$Module.class, fqn = "@aws-cdk/aws-cloudwatch.CfnMetricStreamProps")
@software.amazon.jsii.Jsii.Proxy(CfnMetricStreamProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnMetricStreamProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::CloudWatch::MetricStream.FirehoseArn`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getFirehoseArn();

    /**
     * `AWS::CloudWatch::MetricStream.OutputFormat`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getOutputFormat();

    /**
     * `AWS::CloudWatch::MetricStream.RoleArn`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getRoleArn();

    /**
     * `AWS::CloudWatch::MetricStream.ExcludeFilters`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getExcludeFilters() {
        return null;
    }

    /**
     * `AWS::CloudWatch::MetricStream.IncludeFilters`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getIncludeFilters() {
        return null;
    }

    /**
     * `AWS::CloudWatch::MetricStream.Name`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getName() {
        return null;
    }

    /**
     * `AWS::CloudWatch::MetricStream.Tags`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnMetricStreamProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnMetricStreamProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnMetricStreamProps> {
        private java.lang.String firehoseArn;
        private java.lang.String outputFormat;
        private java.lang.String roleArn;
        private java.lang.Object excludeFilters;
        private java.lang.Object includeFilters;
        private java.lang.String name;
        private java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Sets the value of {@link CfnMetricStreamProps#getFirehoseArn}
         * @param firehoseArn `AWS::CloudWatch::MetricStream.FirehoseArn`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder firehoseArn(java.lang.String firehoseArn) {
            this.firehoseArn = firehoseArn;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricStreamProps#getOutputFormat}
         * @param outputFormat `AWS::CloudWatch::MetricStream.OutputFormat`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder outputFormat(java.lang.String outputFormat) {
            this.outputFormat = outputFormat;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricStreamProps#getRoleArn}
         * @param roleArn `AWS::CloudWatch::MetricStream.RoleArn`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder roleArn(java.lang.String roleArn) {
            this.roleArn = roleArn;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricStreamProps#getExcludeFilters}
         * @param excludeFilters `AWS::CloudWatch::MetricStream.ExcludeFilters`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder excludeFilters(software.amazon.awscdk.core.IResolvable excludeFilters) {
            this.excludeFilters = excludeFilters;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricStreamProps#getExcludeFilters}
         * @param excludeFilters `AWS::CloudWatch::MetricStream.ExcludeFilters`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder excludeFilters(java.util.List<? extends java.lang.Object> excludeFilters) {
            this.excludeFilters = excludeFilters;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricStreamProps#getIncludeFilters}
         * @param includeFilters `AWS::CloudWatch::MetricStream.IncludeFilters`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder includeFilters(software.amazon.awscdk.core.IResolvable includeFilters) {
            this.includeFilters = includeFilters;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricStreamProps#getIncludeFilters}
         * @param includeFilters `AWS::CloudWatch::MetricStream.IncludeFilters`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder includeFilters(java.util.List<? extends java.lang.Object> includeFilters) {
            this.includeFilters = includeFilters;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricStreamProps#getName}
         * @param name `AWS::CloudWatch::MetricStream.Name`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link CfnMetricStreamProps#getTags}
         * @param tags `AWS::CloudWatch::MetricStream.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.core.CfnTag> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnMetricStreamProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnMetricStreamProps build() {
            return new Jsii$Proxy(firehoseArn, outputFormat, roleArn, excludeFilters, includeFilters, name, tags);
        }
    }

    /**
     * An implementation for {@link CfnMetricStreamProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnMetricStreamProps {
        private final java.lang.String firehoseArn;
        private final java.lang.String outputFormat;
        private final java.lang.String roleArn;
        private final java.lang.Object excludeFilters;
        private final java.lang.Object includeFilters;
        private final java.lang.String name;
        private final java.util.List<software.amazon.awscdk.core.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.firehoseArn = software.amazon.jsii.Kernel.get(this, "firehoseArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.outputFormat = software.amazon.jsii.Kernel.get(this, "outputFormat", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.roleArn = software.amazon.jsii.Kernel.get(this, "roleArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.excludeFilters = software.amazon.jsii.Kernel.get(this, "excludeFilters", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.includeFilters = software.amazon.jsii.Kernel.get(this, "includeFilters", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final java.lang.String firehoseArn, final java.lang.String outputFormat, final java.lang.String roleArn, final java.lang.Object excludeFilters, final java.lang.Object includeFilters, final java.lang.String name, final java.util.List<? extends software.amazon.awscdk.core.CfnTag> tags) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.firehoseArn = java.util.Objects.requireNonNull(firehoseArn, "firehoseArn is required");
            this.outputFormat = java.util.Objects.requireNonNull(outputFormat, "outputFormat is required");
            this.roleArn = java.util.Objects.requireNonNull(roleArn, "roleArn is required");
            this.excludeFilters = excludeFilters;
            this.includeFilters = includeFilters;
            this.name = name;
            this.tags = (java.util.List<software.amazon.awscdk.core.CfnTag>)tags;
        }

        @Override
        public final java.lang.String getFirehoseArn() {
            return this.firehoseArn;
        }

        @Override
        public final java.lang.String getOutputFormat() {
            return this.outputFormat;
        }

        @Override
        public final java.lang.String getRoleArn() {
            return this.roleArn;
        }

        @Override
        public final java.lang.Object getExcludeFilters() {
            return this.excludeFilters;
        }

        @Override
        public final java.lang.Object getIncludeFilters() {
            return this.includeFilters;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("firehoseArn", om.valueToTree(this.getFirehoseArn()));
            data.set("outputFormat", om.valueToTree(this.getOutputFormat()));
            data.set("roleArn", om.valueToTree(this.getRoleArn()));
            if (this.getExcludeFilters() != null) {
                data.set("excludeFilters", om.valueToTree(this.getExcludeFilters()));
            }
            if (this.getIncludeFilters() != null) {
                data.set("includeFilters", om.valueToTree(this.getIncludeFilters()));
            }
            if (this.getName() != null) {
                data.set("name", om.valueToTree(this.getName()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudwatch.CfnMetricStreamProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnMetricStreamProps.Jsii$Proxy that = (CfnMetricStreamProps.Jsii$Proxy) o;

            if (!firehoseArn.equals(that.firehoseArn)) return false;
            if (!outputFormat.equals(that.outputFormat)) return false;
            if (!roleArn.equals(that.roleArn)) return false;
            if (this.excludeFilters != null ? !this.excludeFilters.equals(that.excludeFilters) : that.excludeFilters != null) return false;
            if (this.includeFilters != null ? !this.includeFilters.equals(that.includeFilters) : that.includeFilters != null) return false;
            if (this.name != null ? !this.name.equals(that.name) : that.name != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.firehoseArn.hashCode();
            result = 31 * result + (this.outputFormat.hashCode());
            result = 31 * result + (this.roleArn.hashCode());
            result = 31 * result + (this.excludeFilters != null ? this.excludeFilters.hashCode() : 0);
            result = 31 * result + (this.includeFilters != null ? this.includeFilters.hashCode() : 0);
            result = 31 * result + (this.name != null ? this.name.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}
